@@ -34,6 +34,15 @@ if [ $found -eq 0 ] ; then
   DBPATH="${DATAPATH}/de${DB}"
 fi
 
+if [ ! -d ${DBPATH} ] ; then
+    if [ ! -e ${DBPATH}.dat ] ; then
+	echo "Database ${DBPATH} not installed.  Please try"
+        echo "   dpkg-reconfigure fortunes-de"
+        echo "to install more databases."
+        exit
+    fi
+fi
+
 if [ X"$1" = X"-x" ] ; then
    FORTUNE="${FORTUNE} ${DBPATH}"
    shift
