@@ -7,9 +7,9 @@ VERSION="0.11"
 PREFIX=${PREFIX-"/usr/local"}
 
 ### Databases
-FORTUNES=`find data -type f -maxdepth 1 | sed "s?data/??"`
-FORTUNESMORE=`find data-more -type f -maxdepth 1 | sed "s?data-more/??"`
-DIRS=`find data -type d -maxdepth 1 | sed "s?data/??" | sed "/data/d"`
+FORTUNES=`find data -maxdepth 1 -type f | sed "s?data/??"`
+FORTUNESMORE=`find data-more -maxdepth 1 -type f | sed "s?data-more/??"`
+DIRS=`find data -maxdepth 1 -type d | sed "s?data/??" | sed "/data/d"`
 
 DOC="README AUTHORS NEWS LIESMICH GPL-Deutsch"
 DOCDIR=$PREFIX/${DOCDIR:-"doc/fortune-de-$VERSION"}
@@ -29,7 +29,7 @@ if [ _"$1" == _"-utf8" ] ; then
 fi
 
 ### Rezepte
-REZEPTE=`find rezepte -type d -maxdepth 1 | sed "s?rezepte/??" | sed "/rezepte/d"`
+REZEPTE=`find rezepte -maxdepth 1 -type d | sed "s?rezepte/??" | sed "/rezepte/d"`
 REZEPTTMP=rezept.tmp.$$
 
 str_it () {
